@@ -8,6 +8,7 @@ from pytest import fixture
 from airflow_pydantic import (
     BalancerConfiguration,
     BalancerHostQueryConfiguration,
+    BashCommands,
     BashSensor,
     BashSensorArgs,
     BashTask,
@@ -24,6 +25,7 @@ from airflow_pydantic import (
     SSHTask,
     SSHTaskArgs,
     TaskArgs,
+    Variable,
 )
 from airflow_pydantic.airflow import SSHHook
 from airflow_pydantic.testing import pools, variables
@@ -68,6 +70,7 @@ def python_operator_args():
         templates_dict={"test": "test"},
         templates_exts=[".sql", ".hql"],
         show_return_value_in_logs=True,
+        pool=Pool(pool="test-pool-model"),
     )
 
 
@@ -83,7 +86,7 @@ def python_sensor_args():
 @fixture
 def python_operator(python_operator_args):
     return PythonTask(
-        task_id="test_python_operator",
+        task_id="test-python-operator",
         **python_operator_args.model_dump(exclude_unset=True),
     )
 
@@ -91,7 +94,7 @@ def python_operator(python_operator_args):
 @fixture
 def python_sensor(python_sensor_args):
     return PythonSensor(
-        task_id="test_python_sensor",
+        task_id="test-python-sensor",
         **python_sensor_args.model_dump(exclude_unset=True),
     )
 
@@ -120,7 +123,7 @@ def bash_sensor_args():
 @fixture
 def bash_operator(bash_operator_args):
     return BashTask(
-        task_id="test_bash_operator",
+        task_id="test-bash-operator",
         **bash_operator_args.model_dump(exclude_unset=True),
     )
 
@@ -128,7 +131,7 @@ def bash_operator(bash_operator_args):
 @fixture
 def bash_sensor(bash_sensor_args):
     return BashSensor(
-        task_id="test_bash_sensor",
+        task_id="test-bash-sensor",
         **bash_sensor_args.model_dump(exclude_unset=True),
     )
 
@@ -139,7 +142,7 @@ def ssh_operator_args():
         ssh_conn_id="test",
         ssh_hook="airflow_pydantic.tests.conftest.hook",
         pool="blerg",
-        command="test",
+        command=["test1", "test2"],
         do_xcom_push=True,
         cmd_timeout=10,
         get_pty=True,
@@ -150,7 +153,7 @@ def ssh_operator_args():
 @fixture
 def ssh_operator(ssh_operator_args):
     return SSHTask(
-        task_id="test_ssh_operator",
+        task_id="test-ssh-operator",
         **ssh_operator_args.model_dump(exclude_unset=True),
     )
 
@@ -163,8 +166,7 @@ def balancer():
                 Host(
                     name="test_host",
                     username="test_user",
-                    password_variable="VAR",
-                    password_variable_key="password",
+                    password=Variable(key="VAR", deserialize_json=True),
                 ),
             ]
         )
@@ -172,9 +174,10 @@ def balancer():
 
 @fixture
 def ssh_operator_balancer(ssh_operator_args, balancer):
+    ssh_operator_args.command = BashCommands(commands=["test1", "test2"], login=True, cwd="/tmp", env={"var": "{{ ti.blerg }}"})
     with pools(), variables({"user": "test", "password": "password"}):
         return SSHTask(
-            task_id="test_ssh_operator",
+            task_id="test-ssh-operator",
             **ssh_operator_args.model_dump(exclude_unset=True, exclude=["ssh_hook", "pool"]),
             ssh_hook=BalancerHostQueryConfiguration(
                 kind="select",
@@ -188,7 +191,7 @@ def ssh_operator_balancer(ssh_operator_args, balancer):
 def ssh_operator_balancer_template(ssh_operator_balancer):
     with pools(), variables({"user": "test", "password": "password"}):
         return SSHTask(
-            task_id="test_ssh_operator",
+            task_id="test-ssh-operator",
             template=ssh_operator_balancer,
         )
 
@@ -239,14 +242,14 @@ def supervisor_ssh_cfg():
 
 @fixture
 def supervisor_operator(supervisor_cfg):
-    yield SupervisorTask(task_id="test_supervisor", cfg=supervisor_cfg)
+    yield SupervisorTask(task_id="test-supervisor", cfg=supervisor_cfg)
 
 
 @fixture
 def supervisor_ssh_operator(supervisor_ssh_cfg):
-    host = Host(name="test_host", username="test_user", password_variable="VAR", password_variable_key="password")
+    host = Host(name="test_host", username="test_user", password=Variable(key="VAR", deserialize_json=True))
     yield SupervisorSSHTask(
-        task_id="test_supervisor",
+        task_id="test-supervisor",
         cfg=supervisor_ssh_cfg,
         host=host,
         port=Port(name="test_port", host=host, port=8080),
@@ -393,10 +396,10 @@ def dag_with_attribute_dependencies(dag_args, task_args, supervisor_operator):
         tasks={
             "pre": pre,
             "ha": ha,
-            "retrigger_fail": retrigger_fail,
-            "stop_fail": stop_fail,
-            "retrigger_pass": retrigger_pass,
-            "stop_pass": stop_pass,
+            "retrigger-fail": retrigger_fail,
+            "stop-fail": stop_fail,
+            "retrigger-pass": retrigger_pass,
+            "stop-pass": stop_pass,
         },
     )
 
