@@ -31,7 +31,7 @@ class TestRender:
         assert globals_ == []
         assert (
             task
-            == "SSHOperator(pool=Pool.get_pool('blerg').pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test', username='test'), ssh_conn_id='test', command='test', cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test_ssh_operator')"
+            == "SSHOperator(pool=Pool.get_pool('blerg').pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test', username='test'), ssh_conn_id='test', command=\"bash -lc 'set -ex\\ntest1\\ntest2'\", cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test-ssh-operator')"
         )
 
     def test_render_operator_ssh_host_variable(self, ssh_operator_balancer):
@@ -40,12 +40,12 @@ class TestRender:
             "from airflow.providers.ssh.operators.ssh import SSHOperator",
             "from airflow.models.pool import Pool",
             "from airflow.providers.ssh.hooks.ssh import SSHHook",
-            "from airflow.models.variable import Variable",
+            "from airflow.models.variable import Variable as AirflowVariable",
         ]
         assert globals_ == []
         assert (
             task
-            == "SSHOperator(pool=Pool.create_or_update_pool(name='test_host', slots=8, description='Balancer pool for host(test_host)', include_deferred=False).pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test_host.local', username='test_user', password=Variable.get('VAR', deserialize_json=True)['password']), ssh_conn_id='test', command='test', cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test_ssh_operator')"
+            == "SSHOperator(pool=Pool.create_or_update_pool(name='test_host', slots=8, description='Balancer pool for host(test_host)', include_deferred=False).pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test_host.local', username='test_user', password=AirflowVariable.get('VAR', deserialize_json=True)['password']), ssh_conn_id='test', command='bash -lc \\'export var=\"{{ ti.blerg }}\"\\ncd /tmp\\nset -ex\\ntest1\\ntest2\\'', cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test-ssh-operator')"
         )
 
     def test_render_operator_ssh_host_variable_from_template(self, ssh_operator_balancer_template):
@@ -54,18 +54,18 @@ class TestRender:
             "from airflow.providers.ssh.operators.ssh import SSHOperator",
             "from airflow.models.pool import Pool",
             "from airflow.providers.ssh.hooks.ssh import SSHHook",
-            "from airflow.models.variable import Variable",
+            "from airflow.models.variable import Variable as AirflowVariable",
         ]
         assert globals_ == []
         assert (
             task
-            == "SSHOperator(pool=Pool.create_or_update_pool(name='test_host', slots=8, description='Balancer pool for host(test_host)', include_deferred=False).pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test_host.local', username='test_user', password=Variable.get('VAR', deserialize_json=True)['password']), ssh_conn_id='test', command='test', cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test_ssh_operator')"
+            == "SSHOperator(pool=Pool.create_or_update_pool(name='test_host', slots=8, description='Balancer pool for host(test_host)', include_deferred=False).pool, do_xcom_push=True, ssh_hook=SSHHook(remote_host='test_host.local', username='test_user', password=AirflowVariable.get('VAR', deserialize_json=True)['password']), ssh_conn_id='test', command='bash -lc \\'export var=\"{{ ti.blerg }}\"\\ncd /tmp\\nset -ex\\ntest1\\ntest2\\'', cmd_timeout=10, environment={'test': 'test'}, get_pty=True, task_id='test-ssh-operator')"
         )
 
     def test_render_dag(self, dag):
         assert isinstance(dag, Dag)
         assert (
-            dag.render(debug_filename="airflow_pydantic/tests/rendered/dag.py")
+            dag.render(debug_filename="airflow_pydantic/tests/core/rendered/dag.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 
@@ -98,7 +98,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -110,13 +110,14 @@ with DAG(
     },
 ) as dag:
     task1 = PythonOperator(
+        pool=Pool.get_pool("test-pool-model").pool,
         python_callable=foo,
         op_args=["test"],
         op_kwargs={"test": "test"},
         templates_dict={"test": "test"},
         templates_exts=[".sql", ".hql"],
         show_return_value_in_logs=True,
-        task_id="test_python_operator",
+        task_id="test-python-operator",
         dag=dag,
     )
     task2 = BashOperator(
@@ -128,7 +129,7 @@ with DAG(
         skip_on_exit_code=99,
         cwd="test",
         output_processor=foo,
-        task_id="test_bash_operator",
+        task_id="test-bash-operator",
         dag=dag,
     )
     task3 = SSHOperator(
@@ -136,15 +137,15 @@ with DAG(
         do_xcom_push=True,
         ssh_hook=SSHHook(remote_host="test", username="test"),
         ssh_conn_id="test",
-        command="test",
+        command="bash -lc 'set -ex\\ntest1\\ntest2'",
         cmd_timeout=10,
         environment={"test": "test"},
         get_pty=True,
-        task_id="test_ssh_operator",
+        task_id="test-ssh-operator",
         dag=dag,
     )
-    task4 = BashSensor(bash_command="test", task_id="test_bash_sensor", dag=dag)
-    task5 = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test_python_sensor", dag=dag)
+    task4 = BashSensor(bash_command="test", task_id="test-bash-sensor", dag=dag)
+    task5 = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test-python-sensor", dag=dag)
 """
         )
         if _HAVE_AIRFLOW_SSH:
@@ -159,7 +160,7 @@ with DAG(
         dag.tasks["task3"].dependencies = ["task1", "task2"]
         assert isinstance(dag, Dag)
         assert (
-            dag.render(debug_filename="airflow_pydantic/tests/rendered/dependencies.py")
+            dag.render(debug_filename="airflow_pydantic/tests/core/rendered/dependencies.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 
@@ -192,7 +193,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -204,13 +205,14 @@ with DAG(
     },
 ) as dag:
     task1 = PythonOperator(
+        pool=Pool.get_pool("test-pool-model").pool,
         python_callable=foo,
         op_args=["test"],
         op_kwargs={"test": "test"},
         templates_dict={"test": "test"},
         templates_exts=[".sql", ".hql"],
         show_return_value_in_logs=True,
-        task_id="test_python_operator",
+        task_id="test-python-operator",
         dag=dag,
     )
     task2 = BashOperator(
@@ -222,7 +224,7 @@ with DAG(
         skip_on_exit_code=99,
         cwd="test",
         output_processor=foo,
-        task_id="test_bash_operator",
+        task_id="test-bash-operator",
         dag=dag,
     )
     task3 = SSHOperator(
@@ -230,15 +232,15 @@ with DAG(
         do_xcom_push=True,
         ssh_hook=SSHHook(remote_host="test", username="test"),
         ssh_conn_id="test",
-        command="test",
+        command="bash -lc 'set -ex\\ntest1\\ntest2'",
         cmd_timeout=10,
         environment={"test": "test"},
         get_pty=True,
-        task_id="test_ssh_operator",
+        task_id="test-ssh-operator",
         dag=dag,
     )
-    task4 = BashSensor(bash_command="test", task_id="test_bash_sensor", dag=dag)
-    task5 = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test_python_sensor", dag=dag)
+    task4 = BashSensor(bash_command="test", task_id="test-bash-sensor", dag=dag)
+    task5 = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test-python-sensor", dag=dag)
     task1 >> task2
     task1 >> task3
     task2 >> task3
@@ -253,7 +255,7 @@ with DAG(
     def test_render_with_externals(self, dag_with_external):
         assert isinstance(dag_with_external, Dag)
         assert (
-            dag_with_external.render(debug_filename="airflow_pydantic/tests/rendered/externals.py")
+            dag_with_external.render(debug_filename="airflow_pydantic/tests/core/rendered/externals.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 
@@ -283,7 +285,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -295,13 +297,14 @@ with DAG(
     },
 ) as dag:
     task1 = PythonOperator(
+        pool=Pool.get_pool("test-pool-model").pool,
         python_callable=foo,
         op_args=["test"],
         op_kwargs={"test": "test"},
         templates_dict={"test": "test"},
         templates_exts=[".sql", ".hql"],
         show_return_value_in_logs=True,
-        task_id="test_python_operator",
+        task_id="test-python-operator",
         dag=dag,
     )
     task2 = BashOperator(
@@ -313,7 +316,7 @@ with DAG(
         skip_on_exit_code=99,
         cwd="test",
         output_processor=foo,
-        task_id="test_bash_operator",
+        task_id="test-bash-operator",
         dag=dag,
     )
     task3 = SSHOperator(
@@ -321,11 +324,11 @@ with DAG(
         do_xcom_push=True,
         ssh_hook=hook(),
         ssh_conn_id="test",
-        command="test",
+        command="bash -lc 'set -ex\\ntest1\\ntest2'",
         cmd_timeout=10,
         environment={"test": "test"},
         get_pty=True,
-        task_id="test_ssh_operator",
+        task_id="test-ssh-operator",
         dag=dag,
     )
 """
@@ -339,7 +342,7 @@ with DAG(
     def test_render_with_external_supervisor_config(self, dag_with_supervisor):
         assert isinstance(dag_with_supervisor, Dag)
         assert (
-            dag_with_supervisor.render(debug_filename="airflow_pydantic/tests/rendered/supervisor.py")
+            dag_with_supervisor.render(debug_filename="airflow_pydantic/tests/core/rendered/supervisor.py")
             == """# Generated by airflow-config
 from datetime import datetime, time, timedelta
 from pathlib import Path
@@ -365,7 +368,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -402,7 +405,7 @@ with DAG(
             "port": "*:1234",
             "endtime": time(23, 59, 0, 0),
         },
-        task_id="test_supervisor",
+        task_id="test-supervisor",
         dag=dag,
     )
 """
@@ -416,7 +419,7 @@ with DAG(
 
         assert isinstance(dag_with_supervisor_ssh, Dag)
         assert (
-            dag_with_supervisor_ssh.render(debug_filename="airflow_pydantic/tests/rendered/supervisor_ssh.py")
+            dag_with_supervisor_ssh.render(debug_filename="airflow_pydantic/tests/core/rendered/supervisor_ssh.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 from pathlib import Path
@@ -424,7 +427,7 @@ from pathlib import Path
 from airflow.models import DAG
 from airflow_supervisor.airflow.ssh import SupervisorSSH
 
-from airflow_pydantic import Host, Port
+from airflow_pydantic import Host, Port, Variable
 
 with DAG(
     description="",
@@ -444,7 +447,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -479,11 +482,11 @@ with DAG(
             "config_path": Path("/an/arbitrary/path/supervisord.conf"),
             "working_dir": Path("/an/arbitrary/path"),
         },
-        host=Host(name="test_host", username="test_user", password_variable="VAR", password_variable_key="password"),
+        host=Host(name="test_host", username="test_user", password=Variable(key="VAR", deserialize_json=True)),
         port=Port(
-            name="test_port", host=Host(name="test_host", username="test_user", password_variable="VAR", password_variable_key="password"), port=8080
+            name="test_port", host=Host(name="test_host", username="test_user", password=Variable(key="VAR", deserialize_json=True)), port=8080
         ),
-        task_id="test_supervisor",
+        task_id="test-supervisor",
         dag=dag,
     )
 """
@@ -499,7 +502,7 @@ with DAG(
         assert isinstance(dag, Dag)
         assert isinstance(dag, Dag)
         assert (
-            dag.render(debug_filename="airflow_pydantic/tests/rendered/sensor.py")
+            dag.render(debug_filename="airflow_pydantic/tests/core/rendered/sensor.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 
@@ -552,7 +555,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
@@ -563,7 +566,7 @@ with DAG(
         "task_display_name": "test",
     },
 ) as dag:
-    test_python_sensor = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test_python_sensor", dag=dag)
+    test_python_sensor = PythonSensor(python_callable=foo, op_args=["test"], op_kwargs={"test": "test"}, task_id="test-python-sensor", dag=dag)
 """
         )
         # Can't eval due to null param
@@ -572,7 +575,7 @@ with DAG(
 
     def test_render_dag_with_attribute_dependencies(self, dag_with_attribute_dependencies):
         assert (
-            dag_with_attribute_dependencies.render(debug_filename="airflow_pydantic/tests/rendered/attr.py")
+            dag_with_attribute_dependencies.render(debug_filename="airflow_pydantic/tests/core/rendered/attr.py")
             == """# Generated by airflow-config
 from datetime import datetime, timedelta
 
@@ -600,7 +603,7 @@ with DAG(
         "email_on_failure": True,
         "email_on_retry": True,
         "retries": 3,
-        "retry_delay": timedelta(300.0),
+        "retry_delay": timedelta(seconds=300.0),
         "start_date": datetime.fromisoformat("2025-01-01T00:00:00"),
         "end_date": datetime.fromisoformat("2026-01-01T00:00:00"),
         "depends_on_past": True,
