@@ -9,7 +9,9 @@ from .bash import *
 from .common import *
 from .env import *
 from .host import *
+from .names import *
 from .param import *
 from .path import *
 from .pool import *
 from .ssh_hook import *
+from .variable import *
